package com.cirs.biz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.cirs.common.annotation.Log;
import com.cirs.common.core.controller.BaseController;
import com.cirs.common.core.domain.AjaxResult;
import com.cirs.common.enums.BusinessType;
import com.cirs.biz.domain.TDataPreprocessing;
import com.cirs.biz.service.ITDataPreprocessingService;
import com.cirs.common.utils.poi.ExcelUtil;
import com.cirs.common.core.page.TableDataInfo;

/**
 * 预处理Controller
 * 
 * @author fuyanting
 * @date 2024-04-30
 */
@RestController
@RequestMapping("/biz/preprocessing")
public class TDataPreprocessingController extends BaseController
{
    @Autowired
    private ITDataPreprocessingService tDataPreprocessingService;

    /**
     * 查询预处理列表
     */
    @PreAuthorize("@ss.hasPermi('biz:preprocessing:list')")
    @GetMapping("/list")
    public TableDataInfo list(TDataPreprocessing tDataPreprocessing)
    {
        startPage();
        List<TDataPreprocessing> list = tDataPreprocessingService.selectTDataPreprocessingList(tDataPreprocessing);
        return getDataTable(list);
    }

    /**
     * 导出预处理列表
     */
    @PreAuthorize("@ss.hasPermi('biz:preprocessing:export')")
    @Log(title = "预处理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TDataPreprocessing tDataPreprocessing)
    {
        List<TDataPreprocessing> list = tDataPreprocessingService.selectTDataPreprocessingList(tDataPreprocessing);
        ExcelUtil<TDataPreprocessing> util = new ExcelUtil<TDataPreprocessing>(TDataPreprocessing.class);
        util.exportExcel(response, list, "预处理数据");
    }

    /**
     * 获取预处理详细信息
     */
    @PreAuthorize("@ss.hasPermi('biz:preprocessing:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tDataPreprocessingService.selectTDataPreprocessingById(id));
    }

    /**
     * 新增预处理
     */
    @PreAuthorize("@ss.hasPermi('biz:preprocessing:add')")
    @Log(title = "预处理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TDataPreprocessing tDataPreprocessing)
    {
        return toAjax(tDataPreprocessingService.insertTDataPreprocessing(tDataPreprocessing));
    }

    /**
     * 修改预处理
     */
    @PreAuthorize("@ss.hasPermi('biz:preprocessing:edit')")
    @Log(title = "预处理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TDataPreprocessing tDataPreprocessing)
    {
        return toAjax(tDataPreprocessingService.updateTDataPreprocessing(tDataPreprocessing));
    }

    /**
     * 删除预处理
     */
    @PreAuthorize("@ss.hasPermi('biz:preprocessing:remove')")
    @Log(title = "预处理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tDataPreprocessingService.deleteTDataPreprocessingByIds(ids));
    }
}
