package com.cirs.biz.controller;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.servlet.http.HttpServletResponse;

import com.cirs.biz.domain.TSqdDetail;
import com.cirs.biz.service.ITSqdDetailService;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.cirs.common.annotation.Log;
import com.cirs.common.core.controller.BaseController;
import com.cirs.common.core.domain.AjaxResult;
import com.cirs.common.enums.BusinessType;
import com.cirs.biz.domain.TSqd;
import com.cirs.biz.service.ITSqdService;
import com.cirs.common.utils.poi.ExcelUtil;
import com.cirs.common.core.page.TableDataInfo;

/**
 * 双清单管理Controller
 * 
 * @author allen
 * @date 2024-04-30
 */
@RestController
@RequestMapping("/biz/sqd")
public class TSqdController extends BaseController
{
    @Autowired
    private ITSqdService tSqdService;

    @Autowired
    private ITSqdDetailService tSqdDetailService;


    /**
     * 查询双清单管理列表
     */
    @PreAuthorize("@ss.hasPermi('biz:sqd:list')")
    @GetMapping("/list")
    public TableDataInfo list(TSqd tSqd)
    {
        startPage();
        List<TSqd> list = tSqdService.selectTSqdList(tSqd);
        return getDataTable(list);
    }

    /**
     * 导出双清单管理列表
     */
    @PreAuthorize("@ss.hasPermi('biz:sqd:export')")
    @Log(title = "双清单管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TSqd tSqd)
    {
        List<TSqd> list = tSqdService.selectTSqdList(tSqd);
        ExcelUtil<TSqd> util = new ExcelUtil<TSqd>(TSqd.class);
        util.exportExcel(response, list, "双清单管理数据");
    }

    /**
     * 获取双清单管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('biz:sqd:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        List<TSqdDetail> detail = tSqdDetailService.selectTSqdDetailBySqdid(id);
        TSqd sqd = tSqdService.selectTSqdById(id);
        Map<String, Object> resultMap = new HashMap<>();
        resultMap.put("detail", detail);
        resultMap.put("sqd", sqd);
        return success(resultMap);
    }

    /**
     * 新增双清单管理
     */
    @PreAuthorize("@ss.hasPermi('biz:sqd:add')")
    @Log(title = "双清单管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TSqd tSqd)
    {
        tSqd.setCreateBy(getUsername());
        // 保存主记录
        return toAjax(tSqdService.insertTSqd(tSqd));
    }

    /**
     * 修改双清单管理
     */
    @PreAuthorize("@ss.hasPermi('biz:sqd:edit')")
    @Log(title = "双清单管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TSqd tSqd)
    {
        tSqd.setUpdateBy(getUsername());
        return toAjax(tSqdService.updateTSqd(tSqd));
    }

    /**
     * 删除双清单管理
     */
    @PreAuthorize("@ss.hasPermi('biz:sqd:remove')")
    @Log(title = "双清单管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tSqdService.deleteTSqdByIds(ids));
    }
}
