package com.cirs.biz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.cirs.common.annotation.Log;
import com.cirs.common.core.controller.BaseController;
import com.cirs.common.core.domain.AjaxResult;
import com.cirs.common.enums.BusinessType;
import com.cirs.biz.domain.TSqdDetail;
import com.cirs.biz.service.ITSqdDetailService;
import com.cirs.common.utils.poi.ExcelUtil;
import com.cirs.common.core.page.TableDataInfo;

/**
 * SQD明细Controller
 * 
 * @author allen
 * @date 2024-05-01
 */
@RestController
@RequestMapping("/biz/sqddetail")
public class TSqdDetailController extends BaseController
{
    @Autowired
    private ITSqdDetailService tSqdDetailService;

    /**
     * 查询SQD明细列表
     */
    @PreAuthorize("@ss.hasPermi('biz:sqddetail:list')")
    @GetMapping("/list")
    public TableDataInfo list(TSqdDetail tSqdDetail)
    {
        startPage();
        List<TSqdDetail> list = tSqdDetailService.selectTSqdDetailList(tSqdDetail);
        return getDataTable(list);
    }



    /**
     * 导出SQD明细列表
     */
    @PreAuthorize("@ss.hasPermi('biz:sqddetail:export')")
    @Log(title = "SQD明细", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TSqdDetail tSqdDetail)
    {
        List<TSqdDetail> list = tSqdDetailService.selectTSqdDetailList(tSqdDetail);
        ExcelUtil<TSqdDetail> util = new ExcelUtil<TSqdDetail>(TSqdDetail.class);
        util.exportExcel(response, list, "SQD明细数据");
    }

    /**
     * 获取SQD明细详细信息
     */
    @PreAuthorize("@ss.hasPermi('biz:sqddetail:query')")
    @GetMapping(value = "/sqdid/{sqdid}")
    public AjaxResult getInfobysqd(@PathVariable("sqdid") Long sqdid)
    {
        return success(tSqdDetailService.selectTSqdDetailBySqdid(sqdid));
    }


    /**
     * 获取SQD明细详细信息
     */
    @PreAuthorize("@ss.hasPermi('biz:sqddetail:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tSqdDetailService.selectTSqdDetailById(id));
    }

        /**
         * 新增SQD明细
         */
    @PreAuthorize("@ss.hasPermi('biz:sqddetail:add')")
    @Log(title = "SQD明细", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TSqdDetail tSqdDetail)
    {
        return toAjax(tSqdDetailService.insertTSqdDetail(tSqdDetail));
    }

    /**
     * 修改SQD明细
     */
    @PreAuthorize("@ss.hasPermi('biz:sqddetail:edit')")
    @Log(title = "SQD明细", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TSqdDetail tSqdDetail)
    {
        return toAjax(tSqdDetailService.updateTSqdDetail(tSqdDetail));
    }

    /**
     * 删除SQD明细
     */
    @PreAuthorize("@ss.hasPermi('biz:sqddetail:remove')")
    @Log(title = "SQD明细", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tSqdDetailService.deleteTSqdDetailByIds(ids));
    }


    @GetMapping(value = "/sqddetailcount/{id}")
    public boolean checktsExistence(@PathVariable("id") Long id)
    {
        int count = tSqdDetailService.getcountbysqdid(id);
        return count>0;
    }

    @GetMapping(value = "/sqddetailexist/{id}")
    public AjaxResult checktsExistence(@PathVariable("id") Long[] id)
    {
        return success(tSqdDetailService.getcountbysqdidoption(id));
    }

}

