package com.cirs.biz.service.impl;

import java.util.List;
import com.cirs.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.cirs.biz.mapper.TDataPreprocessingMapper;
import com.cirs.biz.domain.TDataPreprocessing;
import com.cirs.biz.service.ITDataPreprocessingService;

/**
 * 预处理Service业务层处理
 * 
 * @author fuyanting
 * @date 2024-04-30
 */
@Service
public class TDataPreprocessingServiceImpl implements ITDataPreprocessingService 
{
    @Autowired
    private TDataPreprocessingMapper tDataPreprocessingMapper;

    /**
     * 查询预处理
     * 
     * @param id 预处理主键
     * @return 预处理
     */
    @Override
    public TDataPreprocessing selectTDataPreprocessingById(Long id)
    {
        return tDataPreprocessingMapper.selectTDataPreprocessingById(id);
    }

    /**
     * 查询预处理列表
     * 
     * @param tDataPreprocessing 预处理
     * @return 预处理
     */
    @Override
    public List<TDataPreprocessing> selectTDataPreprocessingList(TDataPreprocessing tDataPreprocessing)
    {
        return tDataPreprocessingMapper.selectTDataPreprocessingList(tDataPreprocessing);
    }

    /**
     * 新增预处理
     * 
     * @param tDataPreprocessing 预处理
     * @return 结果
     */
    @Override
    public int insertTDataPreprocessing(TDataPreprocessing tDataPreprocessing)
    {
        tDataPreprocessing.setCreateTime(DateUtils.getNowDate());
        return tDataPreprocessingMapper.insertTDataPreprocessing(tDataPreprocessing);
    }

    /**
     * 修改预处理
     * 
     * @param tDataPreprocessing 预处理
     * @return 结果
     */
    @Override
    public int updateTDataPreprocessing(TDataPreprocessing tDataPreprocessing)
    {
        tDataPreprocessing.setUpdateTime(DateUtils.getNowDate());
        return tDataPreprocessingMapper.updateTDataPreprocessing(tDataPreprocessing);
    }

    /**
     * 批量删除预处理
     * 
     * @param ids 需要删除的预处理主键
     * @return 结果
     */
    @Override
    public int deleteTDataPreprocessingByIds(Long[] ids)
    {
        return tDataPreprocessingMapper.deleteTDataPreprocessingByIds(ids);
    }

    /**
     * 删除预处理信息
     * 
     * @param id 预处理主键
     * @return 结果
     */
    @Override
    public int deleteTDataPreprocessingById(Long id)
    {
        return tDataPreprocessingMapper.deleteTDataPreprocessingById(id);
    }
}
