package com.cirs.biz.service.impl;

import java.util.List;
import com.cirs.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.cirs.biz.mapper.TSqdDetailMapper;
import com.cirs.biz.domain.TSqdDetail;
import com.cirs.biz.service.ITSqdDetailService;

/**
 * SQD明细Service业务层处理
 * 
 * @author allen
 * @date 2024-05-01
 */
@Service
public class TSqdDetailServiceImpl implements ITSqdDetailService 
{
    @Autowired
    private TSqdDetailMapper tSqdDetailMapper;

    /**
     * 查询SQD明细
     * 
     * @param id SQD明细主键
     * @return SQD明细
     */
    @Override
    public TSqdDetail selectTSqdDetailById(Long id)
    {
        return tSqdDetailMapper.selectTSqdDetailById(id);
    }

    @Override
    public List<TSqdDetail> selectTSqdDetailBySqdid(Long sqdid) {
        return tSqdDetailMapper.selectTSqdDetailBySqdid(sqdid);
    }

    /**
     * 查询SQD明细列表
     * 
     * @param tSqdDetail SQD明细
     * @return SQD明细
     */
    @Override
    public List<TSqdDetail> selectTSqdDetailList(TSqdDetail tSqdDetail)
    {
        return tSqdDetailMapper.selectTSqdDetailList(tSqdDetail);
    }


    /**
     * 新增SQD明细
     * 
     * @param tSqdDetail SQD明细
     * @return 结果
     */
    @Override
    public int insertTSqdDetail(TSqdDetail tSqdDetail)
    {
        tSqdDetail.setCreateTime(DateUtils.getNowDate());
        return tSqdDetailMapper.insertTSqdDetail(tSqdDetail);
    }

    /**
     * 修改SQD明细
     * 
     * @param tSqdDetail SQD明细
     * @return 结果
     */
    @Override
    public int updateTSqdDetail(TSqdDetail tSqdDetail)
    {
        tSqdDetail.setUpdateTime(DateUtils.getNowDate());
        return tSqdDetailMapper.updateTSqdDetail(tSqdDetail);
    }

    /**
     * 批量删除SQD明细
     * 
     * @param ids 需要删除的SQD明细主键
     * @return 结果
     */
    @Override
    public int deleteTSqdDetailByIds(Long[] ids)
    {
        return tSqdDetailMapper.deleteTSqdDetailByIds(ids);
    }

    /**
     * 删除SQD明细信息
     * 
     * @param id SQD明细主键
     * @return 结果
     */
    @Override
    public int deleteTSqdDetailById(Long id)
    {
        return tSqdDetailMapper.deleteTSqdDetailById(id);
    }

    @Override
    public int getcountbysqdid(Long sqdid) {
        return tSqdDetailMapper.getcountbysqdid(sqdid);
    }

    @Override
    public List getcountbysqdidoption(Long[] id) {
        return tSqdDetailMapper.getcountbysqdidoption(id);
    }
}
