package com.cirs.biz.service.impl;

import java.util.List;

import com.cirs.biz.domain.TSqdDetail;
import com.cirs.biz.mapper.TSqdDetailMapper;
import com.cirs.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.cirs.biz.mapper.TSqdMapper;
import com.cirs.biz.domain.TSqd;
import com.cirs.biz.service.ITSqdService;

/**
 * 双清单管理Service业务层处理
 * 
 * @author allen
 * @date 2024-04-30
 */
@Service
public class TSqdServiceImpl implements ITSqdService 
{
    @Autowired
    private TSqdMapper tSqdMapper;

    @Autowired
    private TSqdDetailMapper tsqdDetailMapper;

    /**
     * 查询双清单管理
     * 
     * @param id 双清单管理主键
     * @return 双清单管理
     */
    @Override
    public TSqd selectTSqdById(Long id)
    {
        return tSqdMapper.selectTSqdById(id);
    }

    /**
     * 查询双清单管理列表
     * 
     * @param tSqd 双清单管理
     * @return 双清单管理
     */
    @Override
    public List<TSqd> selectTSqdList(TSqd tSqd)
    {
        return tSqdMapper.selectTSqdList(tSqd);
    }

    /**
     * 新增双清单管理
     * 
     * @param tSqd 双清单管理
     * @return 结果
     */
    @Override
    public int insertTSqd(TSqd tSqd) {
        tSqd.setCreateTime(DateUtils.getNowDate());

        // 插入主记录
        int result = tSqdMapper.insertTSqd(tSqd);
        if (result > 0) { // 确认主记录插入成功
            long sqdid = tSqd.getId();
            // 插入明细记录前检查集合是否非空
            if (tSqd.getSqddetaillist() != null && !tSqd.getSqddetaillist().isEmpty()) {
                // 设置每个TSqdDetail的sqdId
                for (TSqdDetail detail : tSqd.getSqddetaillist()) {
                    detail.setSqdId(sqdid); // 设置外键关联
                }
                // 批量插入明细记录
                int detailResult = tsqdDetailMapper.batchInsertTSqdDetail(tSqd.getSqddetaillist());
                if (detailResult > 0) {
                    return 1;
                } else {
                    return 0;
                }
            } else {
                return 1;
            }
        } else {
            return 0;
        }
    }





    /**
     * 修改双清单管理
     * 
     * @param tSqd 双清单管理
     * @return 结果
     */
    @Override
    public int updateTSqd(TSqd tSqd)
    {
        tSqd.setUpdateTime(DateUtils.getNowDate());
        System.out.println(tSqd.getSqddetaillist());
        // 遍历 sqdDetailList
        for (TSqdDetail detail : tSqd.getSqddetaillist()) {
            if (detail.getId() != null) {
                // 当 id 不为空时执行更新操作
                tsqdDetailMapper.updateTSqdDetail(detail);
            } else {
                // 当 id 为空时执行增加操作
                detail.setSqdId(tSqd.getId());
                tsqdDetailMapper.insertTSqdDetail(detail);
            }
        }
        return tSqdMapper.updateTSqd(tSqd);
    }

    /**
     * 批量删除双清单管理
     * 
     * @param ids 需要删除的双清单管理主键
     * @return 结果
     */
    @Override
    public int deleteTSqdByIds(Long[] ids)
    {
        return tSqdMapper.deleteTSqdByIds(ids);
    }

    /**
     * 删除双清单管理信息
     * 
     * @param id 双清单管理主键
     * @return 结果
     */
    @Override
    public int deleteTSqdById(Long id)
    {
        return tSqdMapper.deleteTSqdById(id);
    }

}
